##  Assigning To-Dos Created by Automations to Teams
This video tutorial shows how to assign to-dos created by automations to teams instead of individual fixed users. This approach helps avoid the manual maintenance required to ensure the accuracy of respective automation templates.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_vivxv45z/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Fautomation-examples-selected-use-cases%3Fversion%3DCLOUD)
